@@ -64,6 +64,12 @@ def with_session(f):
 
 class Constants():
 
+    @classmethod
+    def values(cls):
+        for key, value in cls.__dict__.items():
+            if not key.startswith('_'):
+                yield value
+
     @classmethod
     def str(cls, value):
         '''Convert status (id) to its string name.'''
@@ -83,6 +89,7 @@ class Status(Constants):
     FAILED_UPLOADING = 6
     FINISHED_UPLOADING = 7
     PARTIAL_RECORDING = 8
+    PAUSED_AFTER_RECORDING = 9
 
 
 class ServiceStatus(Constants):
