@@ -41,6 +41,77 @@ class TestPycaRestInterface(unittest.TestCase):
         session.commit()
         return db.RecordedEvent(event)
 
+    def test_images(self):
+        # Without authentication
+        with ui.app.test_request_context():
+            self.assertEqual(ui.jsonapi.get_images().status_code, 401)
+
+        config.config()['capture']['preview_dir'] = '/tmp'
+
+        # With authentication
+        for preview, response_len in (([], 0), ([__file__], 1)):
+            config.config()['capture']['preview'] = preview
+            with ui.app.test_request_context(headers=self.headers):
+                response = ui.jsonapi.get_images()
+                self.assertEqual(
+                    response.headers['Content-Type'], self.content_type)
+                self.assertEqual(response.status_code, 200)
+                data = json.loads(response.data.decode('utf-8'))
+                self.assertEqual(len(data['data']), response_len)
+
+    def test_name(self):
+        config.config()['agent']['name'] = 'a'
+
+        # Without authentication
+        with ui.app.test_request_context():
+            self.assertEqual(ui.jsonapi.get_name().status_code, 401)
+
+        # With authentication
+        with ui.app.test_request_context(headers=self.headers):
+            response = ui.jsonapi.get_name()
+            self.assertEqual(
+                response.headers['Content-Type'], self.content_type)
+            self.assertEqual(response.status_code, 200)
+            data = json.loads(response.data.decode('utf-8'))
+            self.assertEqual(data['meta']['name'], 'a')
+
+    def test_logs(self):
+        # Without authentication
+        with ui.app.test_request_context():
+            self.assertEqual(ui.jsonapi.logs().status_code, 401)
+
+        # With authentication but without command
+        with ui.app.test_request_context(headers=self.headers):
+            self.assertEqual(ui.jsonapi.logs().status_code, 404)
+
+        config.config()['ui']['log_command'] = 'echo test'
+
+        # With authentication
+        with ui.app.test_request_context(headers=self.headers):
+            response = ui.jsonapi.logs()
+            self.assertEqual(
+                response.headers['Content-Type'], self.content_type)
+            self.assertEqual(response.status_code, 200)
+            data = json.loads(response.data.decode('utf-8'))
+            self.assertEqual(len(data['data']), 1)
+            self.assertEqual(data['data'][0]['attributes']['lines'], ['test'])
+
+    def test_metrics(self):
+        # Without authentication
+        with ui.app.test_request_context():
+            self.assertEqual(ui.jsonapi.metrics().status_code, 401)
+
+        # With authentication
+        with ui.app.test_request_context(headers=self.headers):
+            response = ui.jsonapi.metrics()
+            self.assertEqual(
+                response.headers['Content-Type'], self.content_type)
+            self.assertEqual(response.status_code, 200)
+            keys = json.loads(response.data.decode('utf-8'))['meta'].keys()
+            expect = {'disk_usage_in_bytes', 'load', 'memory_usage_in_bytes',
+                      'services', 'upstream'}
+            self.assertEqual(set(keys), expect)
+
     def test_mediatype_param(self):
         # JSONAPI must respond with 415 when mediatype parameters are present
         param_headers = self.headers.copy()
