@@ -37,15 +37,31 @@ class TestPycaUI(unittest.TestCase):
         with ui.app.test_request_context(headers=self.auth):
             self.assertEqual(ui.home().status_code, 302)
 
-    def test_ui(self):
+    def test_prometheus_metrics(self):
         # Without authentication
         with ui.app.test_request_context():
-            assert ui.serve_image(0).status_code == 401
+            self.assertEqual(ui.prometheus_metrics().status_code, 401)
 
         # With authentication
         with ui.app.test_request_context(headers=self.auth):
-            assert ui.serve_image(9)[1] == 404
+            r = ui.prometheus_metrics()
+            self.assertEqual(r.status_code, 200)
+            data = r.data.decode()
+            self.assertIn('pyca_service_state_info', data)
+            self.assertIn('pyca_events_count', data)
+            self.assertIn('ingest', data)
+            self.assertIn('upcoming', data)
+            r.close()
+
+    def test_ui(self):
+        # Without authentication
+        with ui.app.test_request_context():
+            self.assertEqual(ui.serve_image(0).status_code, 401)
+
+        # With authentication
+        with ui.app.test_request_context(headers=self.auth):
+            self.assertEqual(ui.serve_image(9)[1], 404)
         with ui.app.test_request_context(headers=self.auth):
             r = ui.serve_image(0)
-            assert r.status_code == 200
+            self.assertEqual(r.status_code, 200)
             r.close()
